## Overview
This will be an overview with some deatiled end to end examples.

::: toliman.TolimanOptics
    handler:
        python
    options:
        docstring_style: numpy
        show_source: False
        merge_init_into_class: True
        inherited_members: True
        members:
            - insert
            - __call__
            - remove
            - pop
            - append
            - get 
            - set

::: toliman.TolimanDetector
    handler:
        python
    options:
        docstring_style: numpy
        show_source: False
        merge_init_into_class: True
        inherited_members: True

::: toliman.AlphaCentauri
    handler:
        python
    options:
        docstring_style: numpy
        show_source: False
        merge_init_into_class: True
        inherited_members: True

::: toliman.Background
    handler:
        python
    options:
        docstring_style: numpy
        show_source: False
        merge_init_into_class: True
        inherited_members: True
